pub struct ExtensionWidgetEvent {
pub extension_id: String,
pub event: WidgetEvent,
}Expand description
Event sent from a background notification watcher to the TUI. Carries the source extension id and the parsed widget event.
Fields
extension_id: Stringevent: WidgetEventTrait Implementations
Sourceimpl Clone for ExtensionWidgetEvent
impl Clone for ExtensionWidgetEvent
Sourcefn clone(&self) -> ExtensionWidgetEvent
fn clone(&self) -> ExtensionWidgetEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ExtensionWidgetEvent
impl RefUnwindSafe for ExtensionWidgetEvent
impl Send for ExtensionWidgetEvent
impl Sync for ExtensionWidgetEvent
impl Unpin for ExtensionWidgetEvent
impl UnsafeUnpin for ExtensionWidgetEvent
impl UnwindSafe for ExtensionWidgetEvent